QPushButton
{
    background-color: #6bc260;
    background-image: url("@getImagePath(sendButton/sendButton.svg)");
    background-repeat: none;
    background-position: center;
    border: none;
    border-radius: 5px;
    width: 50px;
    height: 50px;
}

QPushButton:hover
{
    background-color: #79c76f;
}

QPushButton:pressed
{
    background-color: #51b244;
}

QPushButton:focus
{
    outline: none;
}
